# 
# Welcome to the Notebook plugin

## Usage

With this plugin you can open, edit and create Jupyter notebooks.

To create new notebooks, you can right-click and click in
_Open new notebook_. You can also click the
<span title="Open new notebook"><b>&plus;</b></span> button.

To open and save notebooks, please press the 
<span title="Options"><b>&#9881;</b></span> button to the right
of this plugin.
